Opinions

## Opinions for Southern Appellate District

#### Step 1. Select or Change Court

Court:

#### Step 2. Search Opinions ...

Need Help?

#### ... OR View By Date

Year of Opinion:
Show all Opinions for Year Hide all Opinions
Click on a date below to view opinions.

SDOrders_05-09-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32125: STATE OF MISSOURI, Plaintiff-Respondent vs. ANTHONY W. KALTER, Defendant-Appellant Author: Judge Don E. Burrell Vote: Reversed and Remanded for New Trial. Bates, P.J., and Lynch, J., Concur
SD32812: STATE OF MISSOURI, Plaintiff-Respondent vs. MICHAEL LEE HOLT, Defendant-Appellant Author: Judge Nancy Steffen Rahmeyer Vote: Affirmed. Scott, J., Concurs in Separate Opinion and Francis, C.J., Concurs
SD32709: State of Missouri, Respondent vs. JACOB W. BOOK, Appellant Author: Judge William W. Francis, Jr. Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32416: FARM BUREAU TOWN & COUNTRY INSURANCE COMPANY OF MISSOURI, Plaintiff-Appellant vs. JAMES AND PATRICIA SHIPMAN, Defendants-Respondents Author: Judge Daniel E. Scott Vote: Francis, C.J., Concurs, Rahmeyer, P.J., Concurs in part; Dissents in part in separate opinion.
SDOrder_05-05-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32731: MARK E. McGUIRE, Claimant-Respondent vs. CHRISTIAN COUNTY, Employer-Appellant, and MISSOURI ASSOCIATION OF COUNTIES, Insurer-Appellant Author: Judge Gary W. Lynch Vote: Affirmed. Bates, P.J., and Burrell, J., Concur
SD32799: JULIA ERSKINE, Petitioner/Respondent, vs. DIRECTOR OF REVENUE, STATE OF MISSOURI, Respondent/Appellant. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded with Directions. Rahmeyer, P.J., and Scott, J., Concur
SD32615: STATE OF MISSOURI, Plaintiff-Respondent, vs. DALE S. OLTEN, SR., Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
SD32679: DEBORAH A. STRATMAN and TIMOTHY M. STRATMAN, Plaintiffs-Respondents, vs. HAZEL I. WAGNER, Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
SDOrder-04-28-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32467, SD32495 & SD32586 (Consolidated): CAROL HINESLY, Dunklin County Clerk,Plaintiff/Appellant/Respondent, vs. TOM TODD and KENT HAMPTON, Defendants/Respondents/Cross-Appellants. Author: Gary W. Lynch, Judge Vote: Appeal No. SD32495 Dismissed; Appeal Nos. SD32467 & SD32586 Reversed and Remanded with Instructions. Bates, P.J., and Francis, C.J., Concur
SD32901, SD32906 & SD32907 (Consolidated): JONATHAN SAGE, Claimant-Respondent/Cross-Appellant, v. TALBOT INDUSTRIES, Employer-Appellant/Cross-Respondent, and FIDELITY & GUARANTY INSURANCE COMPANY, Insurer-Appellant/Cross-Respondent, and TREASURER OF THE STATE OF MISSOURI AS CUSTODIAN OF THE SECOND INJURY FUND, Respondent-Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SD32867: STATE OF MISSOURI, Plaintiff-Appellant, vs. JEFFREY BARKER STONE, Defendant-Respondent. Author: Gary W. Lynch, Judge Vote: Affirmed. Bates, P.J., and Burrell, J., Concur
SDOrder-04-23-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32936 & SD32958 (Consolidated): KEVIN JOHNSON, Claimant-Appellant/Cross Respondent, vs. CITY OF CARTHAGE, Employer-Respondent/Cross Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Bates, J., and Francis, Jr., C.J., Concur
SDOrder-04-22-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32777: JOHN MATTHEW CLARK, Petitioner-Respondent, v. DIRECTOR OF REVENUE, STATE OF MISSOURI, Respondent-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
SD32823: POPLAR BLUFF INTERNET, INC., Plaintiff/Appellant, vs. CITY OF POPLAR BLUFF, Defendant/Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32459: STATE OF MISSOURI, Plaintiff-Respondent, vs. JAMES CARL DUKE III, Defendant-Appellant. Author: Mary W. Sheffield, Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concurs
SD32849: DONALD BRANDENBURG, Respondent, vs. TREASURER OF THE STATE OF MISSOURI, CUSTODIAN OF SECOND INJURY FUND, Appellant. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32109: STATE OF MISSOURI, Plaintiff-Respondent, vs. PETER D. HANSEN, Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Directions. Francis, Jr., C.J., and Sheffield, J., Concur
SD32417: STATE OF MISSOURI, Plaintiff-Respondent, vs. CHRISTOPHER RYAN BEARD, Defendant-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Rahmeyer, P.J., and Sheffield, J., Concur
SDOrder-04-15-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32374 & SD32543 (Consolidated): THE BANK OF MISSOURI, Plaintiff-Respondent, vs. SOUTH CREEK PROPERTIES, LLC, HAMMER COLLECTIONS, LLC, MICHAEL and CHARLOTTE DEWLEY, Defendants-Appellants, and TREDWELL ENTERPRISES, INC., Third-Party Defendant-Respondent. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32498: KIM FLORA, Petitioner-Respondent, vs. BRADLEY L. FLORA, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32775: MICHAEL D. BURNS, Appellant, vs. STATE OF MISSOURI, Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD32776: AMANDA MEDLOCK and SAM MEDLOCK, Plaintiffs-Appellants, vs. ST. JOHN'S HEALTH SYSTEM, INC., and ST. JOHN'S CLINIC, INC., Defendants-Respondents. Author: Gary W. Lynch, Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SDOrder-04-03-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32636: STATE OF MISSOURI, Plaintiff-Respondent, vs. TENA D. CADY, Defendant-Appellant. Author: Gary W. Lynch, Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SD32887: In the Interest of: D.J.G., Minor, MISSOURI DEPARTMENT OF SOCIAL SERVICES, CHILDREN'S DIVISION, and, HOWELL COUNTY JUVENILE OFFICE, Petitioners-Respondents. vs. A.B., Natural Father, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32761: In The Estate Of: KENNETH SUMMER, JR., Respondent-Respondent, v. MISSOURI DEPARTMENT OF MENTAL HEALTH, Petitioner-Appellant. Author: Jeffrey W. Bates, Presiding Judge Vote: Reversed and Remanded. Lynch, J., and Burrell, J., Concur
SD32396: DOUG A. HOLMES, Respondent, vs. AMY F. HOLMES, Appellant. Author: Daniel E. Scott, Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Directions. Rahmeyer, P.J., Dissents in Separate Opinion, Francis, Jr., C.J., Concurs
SDOrder-03-28-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32427: STATE OF MISSOURI, Plaintiff-Respondent, vs. SHELBY A. GAY, Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
SDOrder-03-27-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32681: COLE ANDREW ANYAN, Petitioner-Respondent, vs. DIRECTOR OF REVENUE, STATE OF MISSOURI, Respondent-Appellant. Author: Mary W. Sheffield, Judge Vote: Reversed and Remanded with Instructions. Lynch, J., and Burrell, J., Concur
SD32699 and SD32735 (Consolidated): THE EXECUTIVE BOARD OF THE MISSOURI BAPTIST CONVENTION, Plaintiff/Appellant, vs. WINDERMERE BAPTIST CONFERENCE CENTER, INC., JAMES L. HILL, RELIANCE TRUST COMPANY, NATIONAL CITY BANK OF THE MIDWEST, CONSOLIDATED MORTGAGE, INC., and FIRST AMERICAN TITLE MISSOURI AGENCY, INC., Defendants/Respondents. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J. - Concurs Scott, J. - Concurs in Separate Opinion
SD32661 and SD32662: STATE OF MISSOURI, Plaintiff-Appellant, vs. KELLY ANN BURY, Defendant-Respondent. Author: Mary W. Sheffield, Judge Vote: Reversed and Remanded. Bates, P.J., and Burrell, J., Concur
SD32496: INTERNATIONAL DIVISION, INC., Plaintiff-Appellant, vs. DeWITT AND ASSOCIATES, INC., Defendant-Respondent. Author: Gary W. Lynch, Judge Vote: Reversed and Remanded. Bates, P.J., and Sheffield, J., Concur
SDOrder-03-24-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32632: FARMERS INSURANCE CO., INC., and MID-CENTURY INSURANCE CO., Plaintiffs-Respondents, vs. ROBIN WILSON and DONALD BILLINGSLEY, Defendants-Appellants. Author: Gary W. Lynch, Judge Vote: Affirmed. Bates, P.J., and Sheffield, J., Concur
SDOrder-03-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SDOrder-03-17-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD33124: STATE OF MISSOURI EX REL. CHRIS KOSTER, Relator, vs. THE HONORABLE MARK FITZSIMMONS, ASSOCIATE CIRCUIT JUDGE OF GREENE COUNTY, AND STEVE HELMS, CIRCUIT CLERK, GREENE COUNTY CIRCUIT COURT, Respondents. Author: PER CURIAM Vote: Record and Writ of Habeas Corpus Quashed. Bates, P.J., Lynch, J., and Sheffield, J.
SD32478: RAYDIANT TECHNOLOGY, LLC, Appellant, v. FLY-N-HOG MEDIA GROUP, INC., Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD32173: MARGARET ARD and ROBERT COMELY, Petitioners-Respondents, v. SHANNON COUNTY COMMISSION, Respondent-Appellant. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SD32236: REJA LYNN COOPER, n/k/a REJA LYNN SPAENY, Petitioner-Appellant, vs. RONALD FRANCIS COOPER, Respondent-Respondent. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32758: ELLEN A. WISS and O. ELIZABETH CORBETT, Plaintiffs-Respondents, vs. GENE W. SPITZMILLER, Defendant/Trustee/Beneficiary-Appellant, and SHARON E. GUNN, Defendant/Trustee/Beneficiary-Respondent, and LINDA J. BRIDGER, Defendant/Beneficiary-Respondent. Author: Don E. Burrell, Judge Vote: Remanded with Directions. Lynch, J., and Sheffield, J., Concur
SD32757: ROBERTS HOLDINGS, INC., Plaintiff-Appellant, vs. BECCA'S BARKERY, INC., STEVEN KALCH, and REBECCA E. KALCH, Defendants-Respondents. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Sheffield, J., Concur
SD32794: DEBORAH K. MORRIS, Personal Representative of the Estate of Steven W. Groves, Deceased, Appellant, vs. TRUST COMPANY OF THE OZARKS, as Trustee of the William and Kathryn Groves Trust Under Agreement dated July 2, 1991, as amended, Maurice Houghton, Martha Rains, Louise Zook, Evangeline Skelton, John Jack Munsey, Park University, and Fitchburg State College, Respondents. Author: Daniel E. Scott, Judge Vote: Affirmed. Lynch, J., and Bates, P.J., Concur
SD32627: KATHY LYNN SHAFER, Petitioner/Appellant, vs. DANIEL DEL SHAFER, Respondent/Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded in Part with Directions; Affirmed in Part. Rahmeyer, P.J., and Scott, J., Concur
SD32326: BRYAN LEE STEELE, Petitioner/Respondent, vs. JUDY ANN STEELE, Respondent/Appellant. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SDOrder-03-10-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32382 and SD32406 (Consolidated): GRAU CONTRACTING, INC., Plaintiff, vs. CAPTIVA LAKE INVESTMENTS, LLC, Appellant/Cross-Respondent, MISSOURI BUILDERS SERVICE, INC., Respondent/Cross-Appellant, QUESTEC CONTRUCTORS, INC., BUTLER SUPPLY, INC., HOUSE OF CARPET, INC., and MEYER ELECTRIC CO., INC., Respondents. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD31479: TERRY A. GUENGERICH and LORRAINE GUENGERICH, Plaintiffs-Appellants, v. KAYLA BARKER and CLARENCE EDWARD HIGGINS, JR., Defendants-Respondents. Author: Jeffrey W. Bates, Judge Vote: Affirmed as Modified. Barney, Sr., J. - Concurs Scott, J. - Concurs in Part and Dissents in Part (Separate Opinion)
SDOrder-03-05-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32688: 2 MIKES, INC., Plaintiff-Appellant, vs. TURNING LEAF PROPERTIES, LLC, Defendant-Respondent. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Sheffield, J., Concur
SD32564: In Re the Marriage of: SCOTT D. YONKER, and VALERIE K. YONKER, SCOTT DAMIAN YONKER, Petitioner-Respondent, vs. VALERIE KAY YONKER, n/k/a VALERIE KAY BOYCE, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Instructions. Bates, P.J., and Lynch, J., Concur
SD32710: LEE HARRELL, Movant-Appellant, v. STATE OF MISSOURI, Respondent-Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concurs
SD32873 and SD32874 (Consolidated): In the Interest of: A.A.R., and A.N.R., Minors, GREENE COUNTY JUVENILE OFFICE, Petitioner-Respondent, vs. M.S.R., Mother, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concurs
SD32778: CINDY SILLYMAN, Plaintiff-Appellant, vs. DAVID O. BARBE, M.D., and ST. JOHN'S PHYSICIANS AND CLINICS, INC., d/b/a ST. JOHN'S CLINIC, Defendants-Respondents. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concurs
SDOrder-02-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32741: SKAGGS REGIONAL MEDICAL CENTER, Respondent, vs. TAMMIE M. POWERS, Appellant. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concurs
SD32293: STATE OF MISSOURI, Plaintiff-Respondent, vs. BOBBY GLEN ROST, Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concurs
SD32542: STATE OF MISSOURI, Plaintiff-Respondent vs. DANNY K. THOMAS, Defendant-Appellant Author: Judge Mary W. Sheffield Vote: Affirmed. Lynch, J., and Burrell, J., Concur.
SDOrder-02-13-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SDOrder-02-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD31205: JAMES R. BAKER and LINDA BAKER, Plaintiffs-Appellants, and CHARLES E. HIGHTOWER, DIANE HIGHTOWER, MARVIN D. GRIFFITH, MARILYN SUE GRIFFITH, and THE UNKNOWN HEIRS, DEVISEES, GRANTEES, SUCCESSORS AND ASSIGNS OF JAMES ELLIS THOMPSON, JR, DECEASED, Plaintiffs, v. WALNUT BOWLS, INC., Defendant-Respondent. Author: Jeffrey W. Bates, Judge Vote: Reversed and Remanded. Barney, Sr., J., and Scott, J., Concur
SD32827: MARLENE STEWART, Respondent vs. CLINT ZWIEFEL, TREASURER OF THE STATE OF MISSOURI AS CUSTODIAN OF THE SECOND INJURY FUND, Appellant Author: Judge Daniel E. Scott Vote: Affirmed. Rahmeyer, P.J., and Francis, C.J., concur
SD32774: JENNIFER DEARBORN, Claimant-Respondent vs. GREAT SOUTHERN FINANCIAL CORPORATION, Employer-Appellant, DIVISION OF EMPLOYMENT SECURITY, Respondent Author: Judge Gary W. Lynch Vote: Affirmed. Bates, P.J., and Burrell, J., Concur
SD32470: RHONDA PARROTT, as Surviving Spouse of JAMES KELSO PARROT, Deceased, and Individually, Plaintiff-Respondent, vs. SEVERS TRUCKING, LLC, and BRANDON G. BLACK, Defendants-Appellants. Author: Gary W. Lynch, Judge Vote: Reversed and Remanded. Bates, P.J., and Burrell, J., Concur
SD32626 and SD32663: RICKY LEE GRIFFITTS, Plaintiff-Respondent, vs. JAMES M. CAMPBELL, Defendant-Respondent, and BNSF RAILWAY COMPANY and OLD REPUBLIC INSURANCE COMPANY, Intervenors-Appellants. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
SD32633: MARK HOPWOOD and MARY HOPWOOD, Plaintiffs-Respondents, v. CITIFINANCIAL, INC. and ZACHREY B. BOULWARE, Defendants-Appellants. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SD32475: TOM M. ROBERTSON, IAFF LOCAL 2618, ADAM GRINES, LARIN TRENARY, and DANIEL JOBE, Plaintiffs-Respondents, vs. POLICE AND FIREMEN'S PENSION PLAN OF CITY OF JOPLIN, TRUSTEES OF POLICE AND FIREMEN'S PENSION PLAN OF CITY OF JOPLIN, and CITY OF JOPLIN, MISSOURI, Defendants-Appellants. Author: Don E. Burrell, Judge Vote: Reversed and Remanded with Instructions. Lynch, J., and Sheffield, J., Concur
SD32830: LINDA DORRIS, Employee-Respondent, vs. STODDARD COUNTY, Employer-Appellant. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32580: MICHAEL A. TIMBERLAKE, Appellant, vs. STATE OF MISSOURI, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded with Directions. Rahmeyer, P.J., and Scott, J., Concur
SDOrder-01-30-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SDOrder-01-29-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32783: JEFFREY BROYLES, Appellant, vs. DIRECTOR OF REVENUE, STATE OF MISSOURI, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32590: CAROL BALLARD, Claimant-Respondent, v. WOODS SUPERMARKETS, INC., Employer-Appellant, and TREASURER OF THE STATE OF MISSOURI AS CUSTODIAN OF THE SECOND INJURY FUND, Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SD32739: ST. JOHN'S CLINIC, INC., Appellant, vs. PULASKI COUNTY AMBULANCE DISTRICT, Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., Dissents in Separate Opinion, Francis, Jr., C.J., Concurs
SDOrder-01-27-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32759 and SD32760 (Consolidated): IN THE INTEREST OF: D.T.L. and C.J.L., children under seventeen years of age. GREENE COUNTY JUVENILE OFFICE, Petitioner-Respondent, vs. V.D.L., Respondent-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Lynch, J., Concur
SD32526: SANDY JACKSON, Plaintiff-Appellant, v. HAZELRIGG AUTOMOTIVE SERVICE CENTER, INC., Defendant-Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Sheffield, J., Concur
SDOrder-01-24-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32858: In the Matter of KATRINA BARNES, Claimant/Appellant, vs. JASPER PRODUCTS, L.L.C., Employer/Respondent, and MISSOURI DIVISION OF EMPLOYMENT SECURITY, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded with Directions. Rahmeyer, P.J., and Scott, J., Concur
SD32800: STATE OF MISSOURI EX REL. BOB T. BEISLY II, Relator, vs. THE HONORABLE TIMOTHY PERIGO, Respondent. Author: Per Curiam Vote: Permanent Writ in Prohibition Issued. Bates, P.J., Burrell, J., and Sheffield, J., Concur
SD32562: J.T. AND A.T., BY AND THROUGH THEIR FATHER, JOHN TAYLOR, FOR THE DEATH OF THEIR MOTHER, LINDY TAYLOR, and J.T. AS PLAINTIFF AD LITEM, Plaintiffs-Appellants, vs. MARTIN ANBARI, M.D., LITTON & GIDDINGS RADIOLOGICAL ASSOCIATES, P.C., and MICHAEL WORKMAN, M.D., Defendants-Respondents. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SDOrder-01-22-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32620: RICHARD E. BEECHER, Appellant, vs. TERRY L. BEECHER, Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Directions. Rahmeyer, P.J., and Lynch, J., Concur
SD32683: ELIZABETH DOWNING, Employee-Respondent, vs. McDONALD'S SIRLOIN STOCKADE, Employer-Appellant. Author: Mary W. Sheffield, Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concur
SD32457: TAMBRA LESTER, Petitioner-Appellant, v. DEPARTMENT OF SOCIAL SERVICES, FAMILY SUPPORT DIVISION, Respondent-Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Sheffield, J., Concur
SD32413: STATE OF MISSOURI, Plaintiff-Respondent, v. BRENT LONG, Defendant-Appellant. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concur
SD32585: DANNY HARNESS and FAYE SAVAGE, Plaintiffs-Respondents, vs. JIM RICHARDSON, HAZEL THOMAS, BETTY NICHOLS, MIKE PRITCHETT, and RODNEY SANFORD, Defendants-Appellants. Author: Mary W. Sheffield, Judge Vote: Reversed and Remanded with Instructions. Bates, P.J., and Burrell, J., Concur
SD32563: SHERI STEPHENS, Plaintiff/Appellant, vs. SHERIFF W. ARCHIE DUNN, SHERIFF JACK L. MERRITT, RETIRED, C.E. WELLS, JOHN DOE I, JOHN DOE III, and JOHN DOE IV, Defendants/Respondents, and GERALD TUCK, JOHN DOE II, JOHN DOE V, and JOHN B. FREITAS, DO, Defendants. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32541: DONALD PAYNE, Claimant/Appellant, vs. TREASURER OF THE STATE OF MISSOURI, CUSTODIAN OF SECOND INJURY FUND, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SDOrder-01-13-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32843: IN THE INTEREST OF K.J.L., S.L.L., Appellant, vs. GREENE COUNTY JUVENILE OFFICE, Respondent. Author: Daniel E. Scott, Judge Vote: Remanded with Directions. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD32629: ROY MEDLIN, Plaintiff/Appellant, vs. RLC, INC., Defendant/Respondent, and JEREMIAH J. HAYES, et al., Intervenors/Respondents. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., Concurs in result only; and Scott, J., Concurs.
SD32658: In the Matter of JENNA STAFFORD, Claimant/Respondent, vs. GREAT SOUTHERN BANK, Employer/Appellant, and MISSOURI DIVISION OF EMPLOYMENT SECURITY, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded with Directions. Rahmeyer, P.J., Scott, J., Concur
SDOrder-01-07-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)